# Asset for AI-RON MAN Web Application Backend

This asset allows to start an application that exposes a ReST API to fetch fire hazard risk predictions from
projects storage spaces.

## Asset files

Within the (unzipped) folder there are the following files:
1. the file `pyproject.toml` that contains detailed instructions for the application to correctly start and install
the required libraries
2. the file `Dockerfile` which contains specific instructions needed by the Docker engine to build the image
3. the tar archive `asset-be-base` that contains a Docker filesystem needed by the application to start 
4. the file `openapi.yaml` which is a structured document that describes the exposed APIs
using the OpenAPI Specification
4. this README

## Start
### Requirements

Requirements to start the application
- [Docker](https://docs.docker.com/)

### Installation

After downloading the zipped asset folder, please unzip it, put it into a known location and go into the 
(unzipped) folder.
After opening a terminal, by means of the command `ls` you will be able to explore the content of the asset folder
and check that all the modules listed in the previous section are present.
To begin with, please digit the command

```shell
 docker import ./asset-be-base.tar base:latest  
```

This will import the tar archive `asset-be-base` and create a Docker image needed by the application under the name `base`.
Now, in order to start the application, you need to launch the build command

```shell
docker build -t asset-be-img -f ./Dockerfile-asset-be .
```

and then launch the service using the command:

```shell
docker run --name asset-be -p 8000:8000 asset-be-img
```

The application will be up and running once you will see on the logs printed something like

```shell
INFO:     Application startup complete.
```

The web application will be available on the local address 

```shell
localhost:8000
```

You can then use your preferred ReST client to test the ReST API.

## Documentation

The list of exposed endpoints is available as a YAML file in the asset directory, i.e. the `openapi.yaml` file.  
This file can be read using online tools such as [the Swagger Editor](https://editor.swagger.io/).

## Created with

- [Python](https://www.python.org/)
- [Poetry](https://python-poetry.org/),
- [FastAPI](https://fastapi.tiangolo.com/)
- [Docker](https://docs.docker.com/)

