from datetime import date as date_type, datetime, time as time_type
from typing import Optional
from google.cloud import storage
import os 
import numpy as np
import rasterio
from datasets import load_dataset
from fastapi import HTTPException
import pandas as pd
from source.configs import NDMI_DATASET_ID, PREDICTIONS_DATASET_ID, CUMULATED_DATASET_ID, STD_TIME_FORMAT, \
    IDRO_PREDICTIONS_CONFIGS, IDRO_DATASET_ID, IDRO_DATETIME_FORMAT, STD_DATETIME_FORMAT, NDMI_DATETIME_FORMAT
from source.resources import PredictionResource

def get_latest_wildfire_map(): 

    current_date = datetime.now().strftime("%Y-%m-%d")
    
    #DEMO
    current_date = "2023-09-01" 

    source_blob_name = f"predictions/{current_date}.tif"

    # Replace 'destination_file_name' with the name you want to give to the downloaded file
    destination_file_name = 'current_prediction.tif'

    # initilize the client
    storage_client = storage.Client()

    # Get the bucket
    bucket_name = 'stam-aironman'
    bucket = storage_client.bucket(bucket_name)

    # Get the blob (file) you want to download
    blob = bucket.blob(source_blob_name)

    # Download the file to a local destination
    blob.download_to_filename(destination_file_name)

    with rasterio.open(destination_file_name, 'r') as src:
        image_data = src.read()
        image_data = np.array(image_data).reshape([1,320,320]).squeeze()
    max_value = np.max(image_data)
    risk = "Low"  
    if max_value == 0.5:
        risk = "Medium"
    elif max_value == 1:
        risk = "High"
    
    current_date = datetime.strptime(current_date, "%Y-%m-%d")
    return PredictionResource(timestamp=current_date, data=image_data.tolist(), risk=risk)